@@ -933,6 +933,11 @@ class DataHandler:
             self.save_new_param_json()
             self.delete_roi_vars()
             # self.global_params["need_recalc_eigen_params"] = True
+            if self.filter_params["pca"]:
+                with open(os.path.join(self.save_dir_path,
+                                       'pca_shape.text'), "w") as f:
+                    f.write("shapes")
+                    f.write(str([x.shape for x in self.pca_decomp if type(x)!= bool]))
         return self.dataset_trials_filtered
 
     @property
